@@ -14,7 +14,8 @@ import readline
 import sys
 import termios
 
-from scs_core.sys.logging import Logging
+from getpass import getpass
+
 from scs_core.sys.process_comms import ProcessComms
 
 
@@ -34,15 +35,30 @@ class StdIO(ProcessComms):
     # ----------------------------------------------------------------------------------------------------------------
 
     @staticmethod
-    def prompt(prompt_str):
+    def prompt(request, default=None):
         try:
             termios.tcflush(sys.stdin, termios.TCIOFLUSH)           # flush stdin
         except termios.error:
             pass
 
+        try:
+            prompt_str = request + ' (%s): ' % default if default else request + ': '
+        except TypeError:
+            prompt_str = request + ': '            # no % format in request string
+
         line = input(prompt_str).strip()
 
-        return line.strip()
+        return line if line else default
+
+
+    @staticmethod
+    def password(request):
+        try:
+            termios.tcflush(sys.stdin, termios.TCIOFLUSH)           # flush stdin
+        except termios.error:
+            pass
+
+        return getpass(request).strip()
 
 
     # ----------------------------------------------------------------------------------------------------------------
@@ -81,11 +97,11 @@ class StdIO(ProcessComms):
         if os.path.exists(filename):
             try:
                 readline.read_history_file(filename)
-            except PermissionError as ex:                         # macOS does this sometimes for no good reason
-                logger = Logging.getLogger()
-                logger.error("PermissionError: %s: %s" % (filename, ex))
+            except PermissionError:                     # macOS darwin does this sometimes for no good reason
+                # logger = Logging.getLogger()
+                # logger.error("PermissionError: %s: %s" % (filename, ex))
                 # Filesystem.rm(filename)
-
+                pass
 
     @classmethod
     def save_history(cls, filename):
